@@ -1,6 +1,6 @@
 from copy import copy
 from functools import reduce
-from typing import Any, List, Optional, Sequence, Tuple as TypedTuple, Type, Union
+from typing import Any, List, Optional, Sequence, Tuple as TypedTuple, Type, Union, Set
 
 from pypika.enums import Dialects, JoinType, ReferenceOption, SetOperation
 from pypika.terms import (
@@ -704,6 +704,7 @@ class QueryBuilder(Selectable, Term):
         self._values = []
         self._distinct = False
         self._ignore = False
+
         self._for_update = False
 
         self._wheres = None
@@ -1330,7 +1331,7 @@ class QueryBuilder(Selectable, Term):
         querystring = self._apply_pagination(querystring)
 
         if self._for_update:
-            querystring += self._for_update_sql()
+            querystring += self._for_update_sql(**kwargs)
 
         if subquery:
             querystring = "({query})".format(query=querystring)
@@ -1366,7 +1367,7 @@ class QueryBuilder(Selectable, Term):
 
         return distinct
 
-    def _for_update_sql(self) -> str:
+    def _for_update_sql(self, **kwargs) -> str:
         if self._for_update:
             for_update = ' FOR UPDATE'
         else:
